@@ -1,7 +1,7 @@
 """
 Type annotations for chime-sdk-identity service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/literals/)
 
 Usage::
 
@@ -24,7 +24,10 @@ __all__ = (
     "AppInstanceUserEndpointTypeType",
     "EndpointStatusReasonType",
     "EndpointStatusType",
+    "ChimeSDKIdentityServiceName",
     "ServiceName",
+    "ResourceServiceName",
+    "RegionName",
 )
 
 
@@ -32,6 +35,7 @@ AllowMessagesType = Literal["ALL", "NONE"]
 AppInstanceUserEndpointTypeType = Literal["APNS", "APNS_SANDBOX", "GCM"]
 EndpointStatusReasonType = Literal["INVALID_DEVICE_TOKEN", "INVALID_PINPOINT_ARN"]
 EndpointStatusType = Literal["ACTIVE", "INACTIVE"]
+ChimeSDKIdentityServiceName = Literal["chime-sdk-identity"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -65,6 +69,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -319,3 +324,16 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
+RegionName = Literal["us-east-1"]
