@@ -1,7 +1,7 @@
 """
 Type annotations for chime-sdk-identity service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/type_defs/)
 
 Usage::
 
@@ -13,7 +13,9 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Sequence
+from typing import Dict, List, Sequence
+
+from typing_extensions import NotRequired
 
 from .literals import (
     AllowMessagesType,
@@ -625,7 +627,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
